Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4403)

Unified Diff: chrome/browser/ui/cocoa/browser_window_controller.mm

Issue 11016023: Quickly close tabs/window with long-running unload handlers. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Patch for landing Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/browser.cc ('k') | chrome/browser/ui/gtk/browser_window_gtk.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/cocoa/browser_window_controller.mm
diff --git a/chrome/browser/ui/cocoa/browser_window_controller.mm b/chrome/browser/ui/cocoa/browser_window_controller.mm
index 232a11952408d0a771340e36f51c3749b97b4ade..9c637694dab9e74dfe3286c27a0f4d2cbed505b8 100644
--- a/chrome/browser/ui/cocoa/browser_window_controller.mm
+++ b/chrome/browser/ui/cocoa/browser_window_controller.mm
@@ -594,11 +594,18 @@ enum {
[self saveWindowPositionIfNeeded];
if (!browser_->tab_strip_model()->empty()) {
// Tab strip isn't empty. Hide the frame (so it appears to have closed
// immediately) and close all the tabs, allowing the renderers to shut
// down. When the tab strip is empty we'll be called back again.
[[self window] orderOut:self];
browser_->OnWindowClosing();
+ browser_->tab_strip_model()->CloseAllTabs();
+ return NO;
+ } else if (!browser_->HasCompletedUnloadProcessing()) {
+ // The browser needs to finish running unload handlers.
+ // Hide the window (so it appears to have closed immediately), and
+ // the browser will call us back again when it is ready to close.
+ [[self window] orderOut:self];
return NO;
}
« no previous file with comments | « chrome/browser/ui/browser.cc ('k') | chrome/browser/ui/gtk/browser_window_gtk.cc » ('j') | no next file with comments »
@@ -594,11 +594,18 @@ enum {
[self saveWindowPositionIfNeeded];
if (!browser_->tab_strip_model()->empty()) {
- // Tab strip isn't empty. Hide the frame (so it appears to have closed
+ // Tab strip isn't empty. Hide the window (so it appears to have closed
// immediately) and close all the tabs, allowing the renderers to shut
// down. When the tab strip is empty we'll be called back again.

Powered by Google App Engine
This is Rietveld 408576698